summaryrefslogtreecommitdiff
path: root/chain/src/lib.rs
diff options
context:
space:
mode:
Diffstat (limited to 'chain/src/lib.rs')
-rw-r--r--chain/src/lib.rs9
1 files changed, 7 insertions, 2 deletions
diff --git a/chain/src/lib.rs b/chain/src/lib.rs
index bf3a8b4..f16ebb2 100644
--- a/chain/src/lib.rs
+++ b/chain/src/lib.rs
@@ -61,8 +61,13 @@ impl Edge {
self.forest_source
}
- /// Return the associated bottom edge of the edge from which
- /// onwards we shall perform the reduction.
+ /// Set the associated forest edge of the edge of the edge.
+ pub fn set_forest_source(&mut self, source: PaVi) {
+ self.forest_source = source;
+ }
+
+ /// Set the associated bottom edge of the edge from which onwards
+ /// we shall perform the reduction.
pub fn set_true_source(&mut self, true_source: PaVi) {
self.true_source = true_source;
}